[edk2-devel] [PATCH v3 31/78] NetworkPkg/Dhcp4Dxe: Fix various typos

Philippe Mathieu-Daudé philmd at redhat.com
Fri Feb 7 01:07:44 UTC 2020


From: Antoine Coeur <coeur at gmx.fr>

Fix various typos in comments and documentation.

Cc: Jiaxin Wu <jiaxin.wu at intel.com>
Cc: Siyuan Fu <siyuan.fu at intel.com>
Cc: Maciej Rabeda <maciej.rabeda at intel.com>
Signed-off-by: Antoine Coeur <coeur at gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <philmd at redhat.com>
Reviewed-by: Maciej Rabeda <maciej.rabeda at intel.com>
Signed-off-by: Philippe Mathieu-Daude <philmd at redhat.com>
---
 NetworkPkg/Dhcp4Dxe/Dhcp4Driver.h |  4 ++--
 NetworkPkg/Dhcp4Dxe/Dhcp4Io.h     |  2 +-
 NetworkPkg/Dhcp4Dxe/Dhcp4Option.h | 18 +++++++++---------
 NetworkPkg/Dhcp4Dxe/Dhcp4Driver.c |  8 ++++----
 NetworkPkg/Dhcp4Dxe/Dhcp4Impl.c   |  6 +++---
 NetworkPkg/Dhcp4Dxe/Dhcp4Io.c     | 12 ++++++------
 NetworkPkg/Dhcp4Dxe/Dhcp4Option.c | 26 +++++++++++++-------------
 7 files changed, 38 insertions(+), 38 deletions(-)

diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.h b/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.h
index cebde20dca5b..f6370582cbd1 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.h
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.h
@@ -104,7 +104,7 @@ Dhcp4DriverBindingStop (
                       then a new handle is created. If it is a pointer to an existing UEFI handle,
                       then the protocol is added to the existing UEFI handle.
 
-  @retval EFI_SUCCES            The protocol was added to ChildHandle.
+  @retval EFI_SUCCESS           The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
   @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to create
                                 the child
@@ -128,7 +128,7 @@ Dhcp4ServiceBindingCreateChild (
   @param  This        Pointer to the EFI_SERVICE_BINDING_PROTOCOL instance.
   @param  ChildHandle Handle of the child to destroy
 
-  @retval EFI_SUCCES            The protocol was removed from ChildHandle.
+  @retval EFI_SUCCESS           The protocol was removed from ChildHandle.
   @retval EFI_UNSUPPORTED       ChildHandle does not support the protocol that is being removed.
   @retval EFI_INVALID_PARAMETER Child handle is NULL.
   @retval EFI_ACCESS_DENIED     The protocol could not be removed from the ChildHandle
diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Io.h b/NetworkPkg/Dhcp4Dxe/Dhcp4Io.h
index 01283e5e17b9..0dd6b46b87d0 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Io.h
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Io.h
@@ -108,7 +108,7 @@ DhcpSendMessage (
 /**
   Each DHCP service has three timer. Two of them are count down timer.
   One for the packet retransmission. The other is to collect the offers.
-  The third timer increaments the lease life which is compared to T1, T2,
+  The third timer increments the lease life which is compared to T1, T2,
   and lease to determine the time to renew and rebind the lease.
   DhcpOnTimerTick will be called once every second.
 
diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Option.h b/NetworkPkg/Dhcp4Dxe/Dhcp4Option.h
index 393176c8996d..a58bb1b0baa8 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Option.h
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Option.h
@@ -81,9 +81,9 @@ typedef struct {
 ///
 /// Structure used to describe and validate the format of DHCP options.
 /// Type is the options' data type, such as DHCP_OPTION_INT8. MinOccur
-/// is the minium occurance of this data type. MaxOccur is defined
+/// is the minimum occurrence of this data type. MaxOccur is defined
 /// similarly. If MaxOccur is -1, it means that there is no limit on the
-/// maximum occurance. Alert tells whether DHCP client should further
+/// maximum occurrence. Alert tells whether DHCP client should further
 /// inspect the option to parse DHCP_PARAMETER.
 ///
 typedef struct {
@@ -114,8 +114,8 @@ EFI_STATUS
                                      found
   @param[in]  Context                The opaque parameter for Check
 
-  @retval EFI_SUCCESS            The DHCP packet's options are well formated
-  @retval EFI_INVALID_PARAMETER  The DHCP packet's options are not well formated
+  @retval EFI_SUCCESS            The DHCP packet's options are well formatted
+  @retval EFI_INVALID_PARAMETER  The DHCP packet's options are not well formatted
 
 **/
 EFI_STATUS
@@ -133,7 +133,7 @@ DhcpIterateOptions (
   @param[out] Para                   The variable to save the DHCP parameters.
 
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory to validate the packet.
-  @retval EFI_INVALID_PARAMETER  The options are malformatted
+  @retval EFI_INVALID_PARAMETER  The options are mal-formatted
   @retval EFI_SUCCESS            The options are parsed into OptionPoint
 
 **/
@@ -146,8 +146,8 @@ DhcpValidateOptions (
 /**
   Parse the options of a DHCP packet. It supports RFC 3396: Encoding
   Long Options in DHCP. That is, it will combine all the option value
-  of all the occurances of each option.
-  A little bit of implemenation:
+  of all the occurrences of each option.
+  A little bit of implementation:
   It adopts the "Key indexed counting" algorithm. First, it allocates
   an array of 256 DHCP_OPTION_COUNTs because DHCP option tag is encoded
   as a UINT8. It then iterates the DHCP packet to get data length of
@@ -167,7 +167,7 @@ DhcpValidateOptions (
 
   @retval EFI_NOT_FOUND          Cannot find any option.
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory to parse the packet.
-  @retval EFI_INVALID_PARAMETER  The options are malformatted
+  @retval EFI_INVALID_PARAMETER  The options are mal-formatted
   @retval EFI_SUCCESS            The options are parsed into OptionPoint
 
 **/
@@ -211,7 +211,7 @@ DhcpAppendOption (
                                      function.
 
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory
-  @retval EFI_INVALID_PARAMETER  The options in SeekPacket are malformatted
+  @retval EFI_INVALID_PARAMETER  The options in SeekPacket are mal-formatted
   @retval EFI_SUCCESS            The packet is build.
 
 **/
diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.c b/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.c
index e891b6888307..970141abfe3a 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.c
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Driver.c
@@ -326,7 +326,7 @@ Dhcp4DriverBindingStart (
   }
 
   //
-  // Install the Dhcp4ServiceBinding Protocol onto ControlerHandle
+  // Install the Dhcp4ServiceBinding Protocol onto ControllerHandle
   //
   Status = gBS->InstallMultipleProtocolInterfaces (
                   &ControllerHandle,
@@ -438,7 +438,7 @@ Dhcp4DriverBindingStop (
   DhcpSb = DHCP_SERVICE_FROM_THIS (ServiceBinding);
   if (!IsListEmpty (&DhcpSb->Children)) {
     //
-    // Destroy all the children instances before destory the service.
+    // Destroy all the children instances before destroy the service.
     //
     List = &DhcpSb->Children;
     Status = NetDestroyLinkList (
@@ -523,7 +523,7 @@ DhcpInitProtocol (
                       then a new handle is created. If it is a pointer to an existing UEFI handle,
                       then the protocol is added to the existing UEFI handle.
 
-  @retval EFI_SUCCES            The protocol was added to ChildHandle.
+  @retval EFI_SUCCESS           The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
   @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to create
                                 the child
@@ -617,7 +617,7 @@ Dhcp4ServiceBindingCreateChild (
   @param  This        Pointer to the EFI_SERVICE_BINDING_PROTOCOL instance.
   @param  ChildHandle Handle of the child to destroy
 
-  @retval EFI_SUCCES            The protocol was removed from ChildHandle.
+  @retval EFI_SUCCESS           The protocol was removed from ChildHandle.
   @retval EFI_UNSUPPORTED       ChildHandle does not support the protocol that is being removed.
   @retval EFI_INVALID_PARAMETER Child handle is NULL.
   @retval EFI_ACCESS_DENIED     The protocol could not be removed from the ChildHandle
diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Impl.c b/NetworkPkg/Dhcp4Dxe/Dhcp4Impl.c
index 0b35bdf4df95..82905337908d 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Impl.c
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Impl.c
@@ -64,7 +64,7 @@ EfiDhcp4GetModeData (
                                 not NULL. Otherwise, the state was left unchanged.
   @retval EFI_ACCESS_DENIED     This instance of the EFI DHCPv4 Protocol driver was not in the
                                 Dhcp4Stopped, Dhcp4Init, Dhcp4InitReboot, or Dhcp4Bound state;
-                                Or onother instance of this EFI DHCPv4 Protocol driver is already
+                                Or another instance of this EFI DHCPv4 Protocol driver is already
                                 in a valid configured state.
   @retval EFI_INVALID_PARAMETER Some parameter is NULL.
   @retval EFI_OUT_OF_RESOURCES  Required system resources could not be allocated.
@@ -611,7 +611,7 @@ DhcpYieldControl (
                                 not NULL. Otherwise, the state was left unchanged.
   @retval EFI_ACCESS_DENIED     This instance of the EFI DHCPv4 Protocol driver was not in the
                                 Dhcp4Stopped, Dhcp4Init, Dhcp4InitReboot, or Dhcp4Bound state;
-                                Or onother instance of this EFI DHCPv4 Protocol driver is already
+                                Or another instance of this EFI DHCPv4 Protocol driver is already
                                 in a valid configured state.
   @retval EFI_INVALID_PARAMETER Some parameter is NULL.
   @retval EFI_OUT_OF_RESOURCES  Required system resources could not be allocated.
@@ -805,7 +805,7 @@ EfiDhcp4Start (
   }
 
   //
-  // Check Media Satus.
+  // Check Media Status.
   //
   MediaStatus = EFI_SUCCESS;
   NetLibDetectMediaWaitTimeout (DhcpSb->Controller, DHCP_CHECK_MEDIA_WAITING_TIME, &MediaStatus);
diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Io.c b/NetworkPkg/Dhcp4Dxe/Dhcp4Io.c
index 4728b94c5803..34c72d690a31 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Io.c
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Io.c
@@ -604,7 +604,7 @@ DhcpEndSession (
                                     is, all the option value that we care.
 
   @retval EFI_SUCCESS           The packet is successfully processed.
-  @retval Others                Some error occured.
+  @retval Others                Some error occurred.
 
 **/
 EFI_STATUS
@@ -632,7 +632,7 @@ DhcpHandleSelect (
 
   //
   // Call the user's callback. The action according to the return is as:
-  // 1. EFI_SUCESS: stop waiting for more offers, select the offer now
+  // 1. EFI_SUCCESS: stop waiting for more offers, select the offer now
   // 2. EFI_NOT_READY: wait for more offers
   // 3. EFI_ABORTED: abort the address acquiring.
   //
@@ -679,7 +679,7 @@ DhcpHandleSelect (
                                     is, all the option value that we care.
 
   @retval EFI_SUCCESS           The packet is successfully processed.
-  @retval Others                Some error occured.
+  @retval Others                Some error occurred.
 
 **/
 EFI_STATUS
@@ -772,7 +772,7 @@ DhcpHandleRequest (
                                     is, all the option value that we care.
 
   @retval EFI_SUCCESS           The packet is successfully processed.
-  @retval Others                Some error occured.
+  @retval Others                Some error occurred.
 
 **/
 EFI_STATUS
@@ -856,7 +856,7 @@ DhcpHandleRenewRebind (
                                     is, all the option value that we care.
 
   @retval EFI_SUCCESS           The packet is successfully processed.
-  @retval Others                Some error occured.
+  @retval Others                Some error occurred.
 
 **/
 EFI_STATUS
@@ -1473,7 +1473,7 @@ DhcpRetransmit (
 /**
   Each DHCP service has three timer. Two of them are count down timer.
   One for the packet retransmission. The other is to collect the offers.
-  The third timer increaments the lease life which is compared to T1, T2,
+  The third timer increments the lease life which is compared to T1, T2,
   and lease to determine the time to renew and rebind the lease.
   DhcpOnTimerTick will be called once every second.
 
diff --git a/NetworkPkg/Dhcp4Dxe/Dhcp4Option.c b/NetworkPkg/Dhcp4Dxe/Dhcp4Option.c
index 3b077de11177..37a63022c55f 100644
--- a/NetworkPkg/Dhcp4Dxe/Dhcp4Option.c
+++ b/NetworkPkg/Dhcp4Dxe/Dhcp4Option.c
@@ -195,7 +195,7 @@ DhcpOptionIsValid (
   }
 
   //
   // Validate the occurance of the option unit is with in [MinOccur, MaxOccur]
   //
   Occur = Len / Unit;
 
@@ -230,7 +230,7 @@ DhcpOptionIsValid (
   @param[out] Para                   The variable to save the interested parameter
 
   @retval EFI_SUCCESS            The DHCP option is successfully extracted.
-  @retval EFI_INVALID_PARAMETER  The DHCP option is malformatted
+  @retval EFI_INVALID_PARAMETER  The DHCP option is mal-formatted
 
 **/
 EFI_STATUS
@@ -303,7 +303,7 @@ DhcpGetParameter (
                                      option.
 
   @retval EFI_SUCCESS            All the options are valid
-  @retval EFI_INVALID_PARAMETER  The options are malformatted.
+  @retval EFI_INVALID_PARAMETER  The options are mal-formatted.
 
 **/
 EFI_STATUS
@@ -376,8 +376,8 @@ DhcpIterateBufferOptions (
                                      found
   @param[in]  Context                The opaque parameter for Check
 
-  @retval EFI_SUCCESS            The DHCP packet's options are well formated
-  @retval EFI_INVALID_PARAMETER  The DHCP packet's options are not well formated
+  @retval EFI_SUCCESS            The DHCP packet's options are well formatted
+  @retval EFI_INVALID_PARAMETER  The DHCP packet's options are not well formatted
 
 **/
 EFI_STATUS
@@ -438,7 +438,7 @@ DhcpIterateOptions (
 
 /**
   Call back function to DhcpIterateOptions to compute each option's
-  length. It just adds the data length of all the occurances of this
+  length. It just adds the data length of all the occurrences of this
   Tag. Context is an array of 256 DHCP_OPTION_COUNT.
 
   @param[in]  Tag                    The current option to check
@@ -473,7 +473,7 @@ DhcpGetOptionLen (
 
   @param[in]  Tag                    The option to consolidate its data
   @param[in]  Len                    The length of option data
-  @param[in]  Data                   The data of the option's current occurance
+  @param[in]  Data                   The data of the option's current occurrence
   @param[in]  Context                The context, which is DHCP_OPTION_CONTEXT. This
                                      array is  just a wrap to pass THREE parameters.
 
@@ -517,8 +517,8 @@ DhcpFillOption (
 /**
   Parse the options of a DHCP packet. It supports RFC 3396: Encoding
   Long Options in DHCP. That is, it will combine all the option value
-  of all the occurances of each option.
-  A little bit of implemenation:
+  of all the occurrences of each option.
+  A little bit of implementation:
   It adopts the "Key indexed counting" algorithm. First, it allocates
   an array of 256 DHCP_OPTION_COUNTs because DHCP option tag is encoded
   as a UINT8. It then iterates the DHCP packet to get data length of
@@ -538,7 +538,7 @@ DhcpFillOption (
 
   @retval EFI_NOT_FOUND          Cannot find any option.
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory to parse the packet.
-  @retval EFI_INVALID_PARAMETER  The options are malformatted
+  @retval EFI_INVALID_PARAMETER  The options are mal-formatted
   @retval EFI_SUCCESS            The options are parsed into OptionPoint
 
 **/
@@ -639,7 +639,7 @@ DhcpParseOption (
   @param[out] Para                   The variable to save the DHCP parameters.
 
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory to validate the packet.
-  @retval EFI_INVALID_PARAMETER  The options are malformatted
+  @retval EFI_INVALID_PARAMETER  The options are mal-formatted
   @retval EFI_SUCCESS            The options are parsed into OptionPoint
 
 **/
@@ -770,7 +770,7 @@ DhcpAppendOption (
                                      function.
 
   @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory
-  @retval EFI_INVALID_PARAMETER  The options in SeekPacket are malformatted
+  @retval EFI_INVALID_PARAMETER  The options in SeekPacket are mal-formatted
   @retval EFI_SUCCESS            The packet is build.
 
 **/
@@ -794,7 +794,7 @@ DhcpBuild (
   UINT8                     *Buf;
 
   //
-  // Use an array of DHCP_OPTION to mark the existance
+  // Use an array of DHCP_OPTION to mark the existence
   // and position of each valid options.
   //
   Mark = AllocatePool (sizeof (DHCP_OPTION) * DHCP_MAX_OPTIONS);
@@ -195,7 +195,7 @@ DhcpOptionIsValid (
 
   //
-  // Validate the occurance of the option unit is with in [MinOccur, MaxOccur]
+  // Validate the occurrence of the option unit is with in [MinOccur, MaxOccur]
   //
   Occur = Len / Unit;
-- 
2.21.1


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#53929): https://edk2.groups.io/g/devel/message/53929
Mute This Topic: https://groups.io/mt/71039565/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-





More information about the edk2-devel-archive mailing list